/*=========================================================================

  Program:   Visualization Toolkit
  Module:    vtk_netcdf.h

  Copyright (c) Ken Martin, Will Schroeder, Bill Lorensen
  All rights reserved.
  See Copyright.txt or http://www.kitware.com/Copyright.htm for details.

     This software is distributed WITHOUT ANY WARRANTY; without even
     the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR
     PURPOSE.  See the above copyright notice for more information.

=========================================================================*/
#ifndef __vtk_netcdf_h
#define __vtk_netcdf_h

/* Use the netcdf library configured for VTK.  */
#include <vtknetcdf/netcdf.h>

#endif
